unit TestThread;

interface

uses
  Windows, System.Classes, System.SysUtils, VCLTee.TeeProcs, VCLTee.TeEngine, VCLTee.TeeTools, VCLTee.Chart, VCLTee.Series, VCLTee.TeeSeriesTextEd,
  VCLTee.TeeURL, VCLTee.TeeExcelSource, VCLTee.TeCanvas, VCL.Forms, VCL.Graphics;

type
  TTestThread = class(TThread)
  private
    aForm : TForm;
    aChart : TChart;
    aMetaFile:TMetafile;
    LogList : TStringList;
    procedure AddLog(Line:string);
  protected
    procedure Execute; override;
  public
    constructor Create;
    destructor Destroy; override;
  end;

implementation

{ TTestThread }

procedure TTestThread.AddLog(Line: string);
begin
  if IsConsole then
     Writeln(Line);

  LogList.Add(Line);
  LogList.SavetoFile(ExtractFilePath(Application.ExeName) + 'Log.txt');
end;

constructor TTestThread.Create;
begin
  inherited Create;
  LogList := TStringList.Create;
end;

destructor TTestThread.Destroy;
begin
  LogList.Free;
  inherited;
end;

procedure TTestThread.Execute;
begin
  inherited;
  try
    Sleep(10000);
    AddLog('Start execute');

    aForm := TForm.Create(nil);
    try
      aChart := TChart.Create(aForm);
      aChart.Parent := aForm;

      aChart.Width := 1000;
      aChart.Height := 800;

      aChart.Draw;
      aMetaFile := aChart.TeeCreateMetafile(True, Rect(0,0, aChart.Width, aChart.Height));
      aMetaFile.SaveToFile(ExtractFilePath(Application.ExeName) + 'Test.wmf');
      AddLog('End execute');
      if IsConsole then
         AddLog('Press enter to exit.');
    except
      on e:Exception do
      begin
        AddLog(e.Message);
      end;
    end;
  finally
    aForm.Free;
  end;
end;

end.
